#
# spec file for package python-jsonrpclib-pelix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jsonrpclib-pelix
Version:        0.4.3.3
Release:        1.2
Summary:        JSPN-RPC over HTTP Library for Pelix Remote Services
License:        Apache-2.0
URL:            https://github.com/tcalmant/jsonrpclib/
Source:         https://github.com/tcalmant/jsonrpclib/archive/v%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A Python (2 & 3) JSON-RPC over HTTP that mirrors xmlrpclib syntax.

%prep
%setup -q -n jsonrpclib-%{version}
sed -i -e 's:python$:python3:' tests/cgi-bin/cgi_server.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%{python_sitelib}/*
%license LICENSE
%doc README.md

%changelog
* Wed Jun 19 2024 Dirk Müller <dmueller@suse.com>
- update to 0.4.3.3:
  * Added support for decimal.Decimal objects (see #60). Thanks
    @pourhouse for this improvement.
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v0.4.3.2
  * Reordered PooledJSONRPCServer inheritance definition (#55)
  * Migration of Continuous Integration:
  * Use PyTest instead of Nose
  * Run CI with GitHub Actions instead of Travis-CI
- Update to v0.4.3.1
  * Removed remaining print statements (#52)
- Update to v0.4.3
  * ServerProxy keeps the given query string, as before 0.4.2. This release fixes #51, and a unit test has been added to ensure
    there won't be any regression again on this feature
  * JSON library selection is now made in the jsonrpclib.jsonlib module, using a set of handler classes. This will ease the addition of new libraries.
  * Added support for ujson
  * Fixed Travis-CI builds (migrated from .org to .com and bypassed the coveralls issue with ppc64le)
  * Fixed an issue with the CGI test in Python 3-only environments
- Update to v0.4.2
  * Use urlparse from urllib.parse (Python 3) or urlparse (Python 2)
  * to prepare for the deprecation of urllib.parse.splittype.
  * Thanks to @citrus-it and @markmcclain for this fix.
    (see #44 and #45 for more details)
  * Unix socket clients now send localhost as Host: HTTP field instead of
    the path to the socket
    (see #47).
  * Thanks @markmcclain for this fix.
  * Added a TransportError exception, subclass of ProtocolError, which
    provides more details
    (see #49).
    Thanks @markmcclain for this improvement.
  * Added PowerPC 64 architecture (ppc64le) to Travis CI runs, to ease the
  * integration of new release into RHEL/Ubuntu (see #50 by @kishorkunal-raj)
* Thu Apr 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Apr 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.1:
  * Fixed a size computation issue in the request handler (see #42)
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.0:
  * Added back support of Unix sockets on both server and client side.
  * Note: HTTPS is not supported on server-side Unix sockets
  * Fixed the CGI request handler
  * Fixed the request handler wrapping on server side
- Switch to github tarball for tests
- Run tests
* Fri Nov 17 2017 mimi.vx@gmail.com
- remove uselees _service
- fix rpmlint warnings
* Thu Nov  2 2017 marec@detebe.org
- initial package build
